//****************************************************************************
// @Module        CAN
// @Filename      CAN.C
// @Project       7CAN_1.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C167CR-L
//
// @Compiler      TASKING C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the CAN peripheral.
//                
//
//----------------------------------------------------------------------------
// @Date          12.06.01 15:02:48
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"


// USER CODE BEGIN (CAN_General,1)

// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (CAN_General,2)

// USER CODE END


//****************************************************************************
// @Function      void CAN_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the CAN component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the CAN
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          12.06.01 15:02:48
//
//****************************************************************************

void CAN_vInit(void)
{

  //  ------------ CAN Control/Status Register --------------
  //  start the initialization of the CAN Modul

  BFLD(DP4,0x0020,0x0000);     // set P4.5 (CAN_RxD) to alternate input
                               // P4.6 (CAN_TxD) is set to output by hardware
  C1CSR  = 0x0041;  // set INIT and CCE

  ///  ------------ Bit Timing Register ---------------------
  /// baudrate =  125,000 KBaud
  /// there are 5 time quanta before sample point
  /// there are 4 time quanta after sample point
  /// the (re)synchronization jump width is 2 time quanta
  C1BTR  = 0x3447;  // set Bit Timing Register

  C1GMS  = 0xE0FF;  // set Global Mask Short Register

  C1UGML = 0xFFFF;  // set Upper Global Mask Long Register

  C1LGML = 0xF8FF;  // set Lower Global Mask Long Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 1 ---------------------------
  //  ------------------------------------------------------------------------
  /// Message object 1 is valid
  CAN_OBJ[0].MCR  = 0x5695;    // set Message Control Register

  /// message direction is transmit
  /// standard 11-bit identifier
  /// 8 valid data bytes
  CAN_OBJ[0].MCFG = 0x88;      // set Message Configuration Register

  CAN_OBJ[0].UAR  = 0x0000;    // set Upper Arbitration Register
  CAN_OBJ[0].LAR  = 0x0000;    // set Lower Arbitration Register

  CAN_OBJ[0].Data[0] = objeckt[0];   // set data byte 0
  CAN_OBJ[0].Data[1] = objeckt[1];   // set data byte 1
  CAN_OBJ[0].Data[2] = objeckt[2];   // set data byte 2
  CAN_OBJ[0].Data[3] = objeckt[3];   // set data byte 3
  CAN_OBJ[0].Data[4] = objeckt[4];   // set data byte 4
  CAN_OBJ[0].Data[5] = objeckt[5];   // set data byte 5
  CAN_OBJ[0].Data[6] = objeckt[6];   // set data byte 6
  CAN_OBJ[0].Data[7] = objeckt[7];   // set data byte 7


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 2 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 2 is not valid
  CAN_OBJ[1].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 3 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 3 is not valid
  CAN_OBJ[2].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 4 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 4 is not valid
  CAN_OBJ[3].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 5 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 5 is not valid
  CAN_OBJ[4].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 6 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 6 is not valid
  CAN_OBJ[5].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 7 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 7 is not valid
  CAN_OBJ[6].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 8 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 8 is not valid
  CAN_OBJ[7].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 9 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 9 is not valid
  CAN_OBJ[8].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 10 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 10 is not valid
  CAN_OBJ[9].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 11 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 11 is not valid
  CAN_OBJ[10].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 12 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 12 is not valid
  CAN_OBJ[11].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 13 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 13 is not valid
  CAN_OBJ[12].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 14 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 14 is not valid
  CAN_OBJ[13].MCR  = 0x5555;    // set Message Control Register


  //  ------------------------------------------------------------------------
  /// ----------------- Configure Message Object 15 ---------------------------
  //  ------------------------------------------------------------------------
  /// message object 15 is not valid
  CAN_OBJ[14].MCR  = 0x5555;    // set Message Control Register



  // USER CODE BEGIN (CAN_Init,0)

  // USER CODE END

  /// ------------ CAN Control/Status Register --------------
  //  reset CCE and INIT
  C1CSR = 0x0000;


  // USER CODE BEGIN (CAN_Init,1)

  // USER CODE END

}


//****************************************************************************
// @Function      void CAN_vTransmit(ubyte ObjNr)
//
//----------------------------------------------------------------------------
// @Description   This function triggers the CAN controller to send the 
//                selected message.
//                If the selected message object is a TRANSMIT OBJECT then 
//                this function triggers the sending of a data frame.
//                If however the selected message object is a RECEIVE OBJECT
//                this function triggers the sending of a remote frame.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    Number of the message object to be sent (1-14)
//
//----------------------------------------------------------------------------
// @Date          12.06.01 15:02:48
//
//****************************************************************************

void CAN_vTransmit(ubyte ObjNr)
{
  CAN_OBJ[ObjNr-1].MCR = 0xe7ff;  // set TXRQ,reset CPUUPD
}




// USER CODE BEGIN (CAN_General,3)

// USER CODE END


